@@ -96,6 +96,51 @@ void XSBackref::on_perl_dup (pTHX_ int32_t refcnt) {
     }
 }
 
+static size_t module2path (const char* module, char* path) {
+    char* pathptr = path;
+    while (*module) {
+        if (*module == ':') {
+            *pathptr = '/';
+            ++module;
+        }
+        else *pathptr = *module;
+        ++pathptr;
+        ++module;
+    }
+    *pathptr++ = '.';
+    *pathptr++ = 'p';
+    *pathptr++ = 'm';
+    *pathptr = 0;
+    return pathptr-path;
+}
+
+bool register_package (pTHX_ const char* module, const char* source_module) {
+    char source_module_path[strlen(source_module)+4];
+    size_t source_module_path_len = module2path(source_module, source_module_path);
+
+    HV* inc = get_hv("INC", GV_ADD);
+    SV** ref = hv_fetch(inc, source_module_path, source_module_path_len, 0);
+    if (!ref) return false;
+
+    char module_path[strlen(module)+4];
+    size_t module_path_len = module2path(module, module_path);
+    hv_store(inc, module_path, module_path_len, SvREFCNT_inc(*ref), 0);
+    return true;
+}
+
+void inherit_package (pTHX_ const char* module, const char* parent) {
+    size_t mlen = strlen(module);
+    char module_isa[mlen + 6];
+    memcpy(module_isa, module, mlen);
+    module_isa[mlen]   = ':';
+    module_isa[mlen+1] = ':';
+    module_isa[mlen+2] = 'I';
+    module_isa[mlen+3] = 'S';
+    module_isa[mlen+4] = 'A';
+    module_isa[mlen+5] = 0;
+    av_push(get_av(module_isa, GV_ADD), newSVpv_share(parent, 0));
+}
+
 namespace _tm {
 
     static inline HV* _get_stash (pTHX_ HV* stash)         { return stash; }
