@@ -169,6 +169,8 @@ inline SV* call_super       (pTHX_ CV* cv, SV** args, I32 items, I32 flags = 0)
 inline SV* call_next_method (pTHX_ CV* cv, SV** args, I32 items, I32 flags = 0) { return call_next(aTHX_ cv, args, items, NEXT_METHOD, flags); }
 inline SV* call_next_maybe  (pTHX_ CV* cv, SV** args, I32 items, I32 flags = 0) { return call_next(aTHX_ cv, args, items, NEXT_MAYBE, flags); }
 
+bool register_package (pTHX_ const char* module, const char* source_module);
+void inherit_package  (pTHX_ const char* module, const char* parent);
 
 class XSBackref : public virtual panda::RefCounted {
     public:
